@@ -10,8 +10,10 @@ warnings.filterwarnings("ignore", category=UserWarning)
 
 
 def run(room, y4m, lifetime=360, headless=1, **kwargs):
+    url = kwargs.get('url') or URL
     browser = get_chrome_browser(y4m=y4m, headless=headless)
-    browser.get(f'{URL}/{room}')
+    browser.get(f'{url}/{room}')
+    
     browser.find_element_by_xpath('/html/body/div[2]/div[3]/div/div[3]/button[2]').click()
     # browser.find_element(By.XPATH('/html/body/div[2]/div[3]/div/div[3]/button[2]')).click()
     time.sleep(lifetime)
