@@ -13,13 +13,15 @@ warnings.filterwarnings("ignore", category=UserWarning)
 
 def run(room='videodrone', y4m='./y4m', lifetime=360, 
         headless=1, pin=None, **kwargs):
+    num = kwargs.get('id', random.randrange(1000))
+    suffix = kwargs.get('suffix', 'default')
     
-    suffix = kwargs.get('id', random.randrange(1000))
+    url = kwargs.get('url') or URL
     browser = get_chrome_browser(y4m=y4m, headless=headless)
-    browser.get(f'{URL}/{room}')
+    browser.get(f'{url}/{room}')
     
     time.sleep(3)
-    browser.find_element_by_id('display-name-dialog-input').send_keys(f'videodrone-{suffix}')
+    browser.find_element_by_id('display-name-dialog-input').send_keys(f'videodrone-{suffix}-{num}')
     time.sleep(1)
     browser.find_element_by_id('display-name-dialog-ok').click()
     
